com.timezynk.domain.core-fns


authorize-read-stationclj

(authorize-read-station l f)

authorize-stationclj

(authorize-station l f)

deleteclj

(delete dom-type-collection pre-process-dtc req)

delete-bulkclj

(delete-bulk dom-type-collection pre-process-dtc req)

dom-responseclj

(dom-response doc req _restriction _collects)

get-dtc-nameclj


get-idclj

(get-id dom-type-collection pre-process-dtc req)

indexclj

(index dom-type-collection pre-process-dtc req)

logclj

(log dtc req & options)

pack-docclj

(pack-doc collection doc)

Convert the document values, from json types to server types.

Convert the document values, from json types to server types.
raw docstring

pack-stationclj

(pack-station l)

Add pack station to assembly line

Add pack station to assembly line
raw docstring

patchclj

(patch dom-type-collection pre-process-dtc req)

postclj

(post dom-type-collection pre-process-dtc req)

post-bulkclj

(post-bulk dom-type-collection pre-process-dtc req)

putclj

(put dom-type-collection pre-process-dtc req)

put-archiveclj

(put-archive dom-type-collection pre-process-dtc req)

put-restoreclj

(put-restore dom-type-collection pre-process-dtc req)

validate-doc-input!clj

(validate-doc-input! {:keys [properties]} doc)

Validate the format of the json doc values, and assures they can be converted to the property type on the server side?

Validate the format of the json doc values, and assures they can be converted to the
property type on the server side?
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries